@@ -36,6 +36,7 @@ extern double dmin (double, double);
 extern double dmax (double, double);
 extern double dwin (double, double, double);
 extern void   msg (char *, int, ...);
+extern void   report_wallclock(int, int);
 extern int    report_times (struct time_account *, int, struct tms *, int,
                             double);
 extern int    root_belong (char *, char *);
@@ -49,7 +50,7 @@ extern void   int_reverse (int *);
 extern void   long_reverse (long *);
 extern void   float_reverse (float *);
 extern void   double_reverse (double *);
-extern void   syntax (void);
+extern void   syntax (char *);
 extern double time_to_double (struct date);
 extern int    time_to_int (int, int, int, int, int);
 
