@@ -148,6 +148,12 @@ copy_cblock_parts ( struct c_block* f, struct c_block* t)
         strcpy (t->sampler_codes, f->sampler_codes);
         }
 
+    if (f->vbp_correct != NULLINT)
+        t->vbp_correct = f->vbp_correct;
+
+    if (f->vbp_fit != NULLINT)
+        t->vbp_fit = f->vbp_fit;
+
     for (i=0; i<MAX_SAMP; i++)
         {
         if (f->sampler_delay[i][0].ref != NULLFLOAT)
@@ -160,6 +166,14 @@ copy_cblock_parts ( struct c_block* f, struct c_block* t)
             t->sampler_delay[i][1].rem = f->sampler_delay[i][1].rem;
         }
 
+    if (f->vbp_coeffs[0].ref != NULLFLOAT)
+        for (i=0; i<5; i++)
+            t->vbp_coeffs[i].ref = f->vbp_coeffs[i].ref;
+
+    if (f->vbp_coeffs[0].rem != NULLFLOAT)
+        for (i=0; i<5; i++)
+            t->vbp_coeffs[i].rem = f->vbp_coeffs[i].rem;
+
     if (f->adhoc_poly[0] != NULLFLOAT)
         for (i=0; i<6; i++)
             if (f->adhoc_poly[i] != NULLFLOAT)
@@ -204,6 +218,9 @@ copy_cblock_parts ( struct c_block* f, struct c_block* t)
             
         if (f->pc_phase_offset[i].ref != NULLFLOAT)
             t->pc_phase_offset[i].ref = f->pc_phase_offset[i].ref;
+
+        if (f->vbp_file[i][0] != 0)
+            strcpy (t->vbp_file[i], f->vbp_file[i]);
         }
 
     if (f->gen_cf_record != NULLINT)
@@ -226,10 +243,10 @@ copy_cblock_parts ( struct c_block* f, struct c_block* t)
                                     // and the to-list are present in the resulting to-list
     for (i=0; i<MAXFREQ; i++)                         
         {
-        if (f->frequency[i] != NULLINT)
-            t->frequency[i] &= f->frequency[i];
+        if (f->accept_sbs[i] != NULLINT)
+            t->accept_sbs[i] &= f->accept_sbs[i];
 
-        if (t->frequency[i])        // copy iff this freq. still active
+        if (t->accept_sbs[i])     // copy iff this freq. still active
             {
             for (j=0; j<2; j++)     // copy phases for both polarizations
                 {
@@ -274,6 +291,12 @@ copy_cblock_parts ( struct c_block* f, struct c_block* t)
                 }
             }
         }
+        if (f->chid_rf[0] != 0.0)   // chid_rf[0] is flag for chid override
+            {
+            strncpy (t->chid, f->chid, MAXFREQ);
+            for (j=0; j<strlen (t->chid); j++)
+                t->chid_rf[j] = f->chid_rf[j];
+            }
 
     return(0);
     }
