@@ -41,7 +41,7 @@
 #include "write_lock_mechanism.h"
 #include "fourfit_signal_handler.h"
 
-struct type_param param;                
+struct type_param param;
 struct type_status status;              /* External structure declarations */
 struct mk4_fringe fringe;
 struct mk4_corel cdata;
@@ -54,9 +54,9 @@ struct c_block *cb_head;
 int baseline, base, ncorel_rec, lo_offset, max_seq_no;
 int do_only_new = FALSE;
 int test_mode = FALSE;
-int plot_xpower = TRUE;
 int write_xpower = FALSE;
 int do_accounting = FALSE;
+int do_estimation = FALSE;
 int refringe = FALSE;
 int ap_per_seg = 0;
 int reftime_offset = 0;
@@ -69,7 +69,7 @@ char progname[] = FF_PROGNAME;		// fourfit or fearfit from Makefile
 int msglev = 2;
 char *pexec;                            // ptr to progam executable name
 char version_no[] = FF_VER_NO;		// PACKAGE_VERSION from Makefile
-//char version_no[4] = "3.5";             // Update this with new releases 
+//char version_no[4] = "3.5";             // Update this with new releases
                                         // v2.2  ???        cjl
                                         // v3.0  2001.5.25  rjc  first ver. change
                                         //                       in a long, long time
@@ -93,7 +93,7 @@ main (int argc, char** argv)
     fstruct *files, *fs;
     struct fileset fset;
     bsgstruct *base_sgrp;
-    
+
     //init lockfile data struct
     clear_global_lockfile_data();
 
@@ -114,17 +114,17 @@ main (int argc, char** argv)
                                         /* Trap empty argument list */
     if (argc == 1)
         {
-        syntax();
+        syntax("$HeadURL$");
         return (1);
         }
     pexec = argv[0];                    // point to executable name
                                         /* Initialize IO library allocation */
     cdata.nalloc = 0;
     fringe.nalloc = 0;
-    for (i=0; i<MAXSTATIONS; i++) 
+    for (i=0; i<MAXSTATIONS; i++)
         sdata[i].nalloc = 0;
                                         /* Initialize main array for memory alloc */
-    for (i=0; i<MAXFREQ; i++) 
+    for (i=0; i<MAXFREQ; i++)
         corel[i].data_alloc = FALSE;
                                         /* More initialization */
     msg ("fourfit calling set_defaults...",0);
@@ -168,7 +168,7 @@ main (int argc, char** argv)
             {
             msg ("%sUnable to find abspath for %s, skipping", 2,
                 processmsg, rootname);
-            continue; 
+            continue;
             }
         if (get_vex (rootname, OVEX | EVEX | IVEX | LVEX, "", &root) != 0)
             {
@@ -218,7 +218,7 @@ main (int argc, char** argv)
                                         /* groups requested */
             param.rf_fglist = NULL;
             if (refringe)
-                if ((param.rf_fglist = 
+                if ((param.rf_fglist =
                         check_rflist (fs->baseline, i-1, base_sgrp)) == NULL)
                     continue;
                                         /* This reads the relevant corel file */
@@ -257,14 +257,15 @@ main (int argc, char** argv)
                                         /* errors in ret.  Error reporting is */
                                         /* internal to fringe_search() */
             nbtried++;
-            totpass += npass;
             for (k=0; k<npass; k++)
                 {
-                fs_ret = fringe_search (&root, pass + k);
+                if (totpass > 0 && do_estimation) fs_ret = -3;
+                else fs_ret = fringe_search (&root, pass + k);
                 if (fs_ret < 0) break;
                 ret += fs_ret;
                 }
-            
+            totpass += npass;
+
             if (fs_ret < 0)             /* quit request */
                 {
                 /* avoiding num_ap<0 crash: Hotaka 9/28/2017 */
@@ -280,6 +281,10 @@ main (int argc, char** argv)
                         msg ("quitting by request", 1);
                         user_ok = FALSE;
                     }
+                else if (fs_ret == -3)
+                    {
+                        /* just going through the motions */ ;
+                    }
                 else
                 /* still try to continue */
                     {
@@ -297,7 +302,7 @@ main (int argc, char** argv)
             }                           /* End of baseline loop */
 
                                         /* Successful fringing, update root */
-//      if ((ret < totpass) && (! test_mode)) 
+//      if ((ret < totpass) && (! test_mode))
 //          {
 /*            write_root (&root, rootname);  */
 //          if (do_accounting) account ("Update root files");
@@ -316,7 +321,8 @@ main (int argc, char** argv)
                                         /* Complete accounting and exit */
     if (do_accounting) account ("Report results");
     if (do_accounting) account ("!REPORT");
-    
+    if (do_estimation) report_wallclock(npass, totpass);
+
     //free up control buffers
     free(param.control_file_buff);
     free(param.set_string_buff);
