@@ -12,6 +12,7 @@
 /* new code to search for maximum over ionospheric values 2012.1.27 rjc */
 /* changed ionosphere search to be 3 level                2016.3.9  rjc */
 /* refactored code to be 2 routines, this and ion_search  2016.5.25 rjc */
+/* removed generate_cblock call, it's done in make_passes 2019.2.22 rjc */
 /************************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
@@ -31,16 +32,9 @@ int fringe_search ( struct vex* root, struct type_pass* pass)
     extern struct type_status status;
     extern struct type_param param;
 
-
     msg  ("Baseline %c%c subgroup %c", 1, 
            param.baseline[0], param.baseline[1], pass->pass_data[0].fgroup);
 
-                                        /* Form control block for this pass */
-    if (generate_cblock (root->ovex, pass) != 0)     
-        {
-        msg ("Error generating pass block",2);
-        return (-1);
-        }
                                         /* Currently does default filtering */
     if (apply_filter (pass) != 0)
         {
