@@ -30,11 +30,12 @@ gate_off (struct type_pass* pass, int frq, int ap)
     int period, start_gate, end_gate, duration, acc_period, ap_start, ap_stop;
     int pstart, offset;
     extern struct type_param param;
+    int fcode (char, char *);
                                         /* Get appropriate values from */
                                         /* control blk */
                                         /* Do all in milliseconds for integer */
                                         /* comparisons */
-    freq_no = fcode(pass->pass_data[frq].freq_code);
+    freq_no = fcode(pass->pass_data[frq].freq_code, pass->control.chid);
     mode = pass->control.switched_mode;
 
     period = (int)(pass->control.switched_period * 1000.0);
