@@ -18,6 +18,7 @@
 #include "pass_struct.h"
 #include "meta_struct.h"
 #include "ovex.h"
+#include <stdlib.h>
 
 #define pi 3.141592654
                                         // polarization bit masks
@@ -84,7 +85,7 @@ void generate_text (struct scan_struct *root,
     char polchar[2][2] = {'L', 'R', 'X', 'Y'};
     FILE *popfil;
     char absexec[256], which_command[256];
-    char buffer[32];
+    char buffer[32], *phost;
     static char *pcstr[5]={"","NORMAL","AP BY AP","MANUAL", "MULTITONE"};
     double delta_delay;
     void stripbuf (char *),
@@ -129,6 +130,9 @@ void generate_text (struct scan_struct *root,
     if (param.corr_type == DIFX)
         sprintf (buffer, "Mk4/DiFX %s %s rev %hd", 
                  progname, version_no, fringe.t200->software_rev[0]);
+    else if (param.corr_type == SFXC)
+        sprintf (buffer, "Mk4/SFXC %s %s rev %hd", 
+                 progname, version_no, fringe.t200->software_rev[0]);
     else
         sprintf (buffer, "Mk4/hdw. %s %s rev %hd", 
                  progname, version_no, fringe.t200->software_rev[0]);
@@ -138,10 +142,21 @@ void generate_text (struct scan_struct *root,
     if ((rootname = strrchr (root->filename, '/')) == NULL)
         rootname = root->filename;
     else rootname++;
-    param.baseline[2] = 0;
-    sprintf (buf, "%s, %s, %s", rootname, root->scan_name, param.baseline);
+
+    sprintf (buf, "%s, %s, %c%c", rootname, root->scan_name, 
+                                  param.baseline[0], param.baseline[1]);
     psright (1.0, 0.98, buf);
     strncpy(meta.rt_sn_bl, buf, sizeof(meta.rt_sn_bl));
+
+    setgreen;
+    pscat ("/Helvetica-Bold findfont 140 scalefont setfont\n");
+                                        // print out name of host machine
+    phost = getenv ("HOSTNAME");
+    if (phost != NULL)
+        {
+        sprintf (buffer, "%.31s", phost);
+        psleft (0.0, 0.965, buffer)
+        }
                                         /* Convert to pol. string */
     polars = 0;
     if (param.pol == 0)
@@ -209,7 +224,7 @@ void generate_text (struct scan_struct *root,
     sprintf (buf, "%.8s - %.8s, fgroup %c, pol %s", fringe.t202->ref_name,
                     fringe.t202->rem_name, pass->pass_data[0].fgroup, polstr);
     strncpy(meta.polstr, polstr, sizeof(meta.polstr));
-    pscat ("/Helvetica-Bold findfont 140 scalefont setfont\n");
+    setblack;
     psright (1.0, 0.965, buf);
                                         /* Some solution essentials in a visible spot */
     pscat ("/Helvetica findfont 130 scalefont setfont\n");
