@@ -18,7 +18,7 @@ init_tokens ()
     extern int  token_cat[];              /* in a structure & initialized    */
 
     for (i=0; i<MAX_TOKENS; i++)
-	tokenize (i, "", 0);                  /* initialize all tokens to null */
+    tokenize (i, "", 0);                  /* initialize all tokens to null */
 
 
     /*       token #        string        category      */
@@ -134,6 +134,11 @@ init_tokens ()
     tokenize (SAMPLER_DELAY_R_,"sampler_delay_r", VECTOR_FLOAT_PARAM)
     tokenize (SAMPLER_DELAY_X_,"sampler_delay_x", VECTOR_FLOAT_PARAM)
     tokenize (SAMPLER_DELAY_Y_,"sampler_delay_y", VECTOR_FLOAT_PARAM)
-    tokenize (ION_SMOOTH_,  "ion_smooth",   INT_PARAM)
+    tokenize (ION_SMOOTH_,  "ion_smooth", INT_PARAM)
     tokenize (EST_PC_MANUAL_, "est_pc_manual", INT_PARAM)
+    tokenize (CHAN_IDS_,    "chan_ids",   CHAN_PARAM)
+    tokenize (VBP_CORRECT_, "vbp_correct", INT_PARAM)
+    tokenize (VBP_FIT_,     "vbp_fit",    INT_PARAM)
+    tokenize (VBP_COEFFS_,  "vbp_coeffs", VECTOR_FLOAT_PARAM)
+    tokenize (VBP_FILE_,    "vbp_file",   STRING_PARAM)
     }
