@@ -52,7 +52,8 @@ int parser (void)
         parsed_codes[MAXFREQ],
         *psc,
         chan[2];
-
+                                            // master_codes static so "set" works
+   static char master_codes[MAXFREQ];
    float fval;
 
    struct c_block *cond_start,
@@ -60,7 +61,10 @@ int parser (void)
                                                     of a complex IF condition */
                   *cb_ptr,
                   *cb_tail;                 /* points to last cblock in chain */
+   int fcode (char, char *);
 
+   if (master_codes[0] == '\0')
+       strncpy (master_codes, FCHARS, sizeof (master_codes));
 
    msg ("Following parser triples are token_number:state:category", -2);
 
@@ -128,7 +132,7 @@ int parser (void)
             case CLEAR_FREQS:                /* clear all freq codes to start */
                for (cb_ptr=cond_start; cb_ptr!=NULL; cb_ptr=cb_ptr->cb_chain)
                   for (i=0; i<MAXFREQ; i++)
-                     cb_ptr->frequency[i] = 0;
+                     cb_ptr->accept_sbs[i] = 0;
                                                 /* and then save token number */
                
             case SAVE_TOKEN_NUM:
@@ -285,6 +289,10 @@ int parser (void)
                        cb_ptr -> ion_smooth = tval;
                    else if (toknum == EST_PC_MANUAL_)
                        cb_ptr -> est_pc_manual = tval;
+                   else if (toknum == VBP_CORRECT_)
+                       cb_ptr -> vbp_correct = tval;
+                   else if (toknum == VBP_FIT_)
+                       cb_ptr -> vbp_fit = tval;
                break;
 
 
@@ -302,7 +310,7 @@ int parser (void)
 
                    else if (toknum == PC_PHASE_)  /* is this phase cal phase? */
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
@@ -342,7 +350,7 @@ int parser (void)
                    else if (toknum == PC_PHASE_L_
                          || toknum == PC_PHASE_X_)  // is this L/X/H phase cal phase?
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
@@ -374,7 +382,7 @@ int parser (void)
                    else if (toknum == PC_PHASE_R_
                          || toknum == PC_PHASE_Y_)  // is this R/Y/V phase cal phase?
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
@@ -405,7 +413,7 @@ int parser (void)
 
                    else if (toknum == PC_FREQ_)    /* is this phase cal freq? */
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid phase cal frequency code",2);
@@ -438,7 +446,7 @@ int parser (void)
 
                    else if (toknum == PC_TONEMASK_)  // pcal tone exclusion mask?
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid pcal freq code in tonemask",2);
@@ -456,7 +464,7 @@ int parser (void)
 
                    else if (toknum == GATES_) /*are these freq. switch gates? */
                        {
-                       i = fcode(parsed_codes[nv/2]);
+                       i = fcode(parsed_codes[nv/2], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid gates frequency code",2);
@@ -534,6 +542,30 @@ int parser (void)
                        cb_ptr -> adhoc_poly[nv] = fval;
                        }
 
+                   else if (toknum == VBP_COEFFS_)
+                       {
+                       if (nv > 4)
+                           {
+                           msg ("Must have 5 video bandpass coeffs",2);
+                           return (-1);
+                           }
+                                    // treat integer and float numbers the same way
+                       if (tokens[ntok].category == INTEGER)
+                           fval = tval;
+                       else
+                           fval = float_values[tval];
+                                    // handle specification by either stn or baseline
+                       if (cb_ptr -> baseline[1] == WILDCARD)
+                           cb_ptr -> vbp_coeffs[nv].ref = fval;
+                       else if (cb_ptr -> baseline[0] == WILDCARD)
+                           cb_ptr -> vbp_coeffs[nv].rem = fval;
+                       else
+                           {
+                           cb_ptr -> vbp_coeffs[nv].ref = 0.0;
+                           cb_ptr -> vbp_coeffs[nv].rem = fval;
+                           }
+                       }
+
                    else if (toknum == NOTCHES_)
                        {
                        if (nv > MAXNOTCH*2)
@@ -566,7 +598,7 @@ int parser (void)
 // ##DELAY_OFFS##  for next clause
                    else if (toknum == DELAY_OFFS_) // is this a channel delay offset?
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid delay offset frequency code",2);
@@ -597,7 +629,7 @@ int parser (void)
 
                    else if (toknum == DELAY_OFFS_L_ || toknum == DELAY_OFFS_X_) 
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid delay offset frequency code",2);
@@ -622,7 +654,7 @@ int parser (void)
 
                    else if (toknum == DELAY_OFFS_R_ || toknum == DELAY_OFFS_Y_) 
                        {
-                       i = fcode(parsed_codes[nv]);
+                       i = fcode(parsed_codes[nv], master_codes);
                        if (i<0 || i>MAXFREQ-1)
                            {
                            msg ("Invalid delay offset frequency code",2);
@@ -694,6 +726,21 @@ int parser (void)
                            cb_ptr -> sampler_delay[nv][RYV].rem = fval;
                            }
                        }
+                   else if (toknum == CHAN_IDS_)  // is this channel id override?
+                       {
+                       if (nv == 0)       // save ch string as new master copy
+                           {
+                           strncpy (master_codes, parsed_codes, sizeof (master_codes));
+                           strncpy (cb_ptr->chid, parsed_codes, sizeof (master_codes));
+                           }
+                                          // allow int or float input values
+                       if (tokens[ntok].category == INTEGER)
+                           fval = tval;
+                       else
+                           fval = float_values[tval];
+                       cb_ptr -> chid_rf[nv] = fval;
+                       }
+
                nv++;                       /* bump index for next vector parm */
                break;
 
@@ -727,7 +774,7 @@ int parser (void)
                        chan[1] = '#';
                    }
 
-               i = fcode(chan[0]);                       /* get freq. array index */
+               i = fcode(chan[0], master_codes);     /* get freq. array index */
                if (i<0 || i>MAXFREQ-1 || sideband<0) /* trap error conditions */
                    {
                    msg ("Errant freq element: %c%c", 2, chan[0], chan[1]);
@@ -735,7 +782,7 @@ int parser (void)
                    }
                                         /* OK, load into appropriate c_blocks */
                for (cb_ptr=cond_start; cb_ptr!=NULL; cb_ptr=cb_ptr->cb_chain)
-                   cb_ptr -> frequency[i] = sideband; 
+                   cb_ptr -> accept_sbs[i] = sideband; 
                break;
 
            case INSERT_STRING:                   // handle all string arguments
@@ -789,6 +836,15 @@ int parser (void)
                        else if (cb_ptr -> baseline[0] == WILDCARD) // rem station
                            strncpy (cb_ptr -> plot_data_dir[1],
                                     char_values+tval, 256);
+                       }
+                                // video bandpass file name
+               else if (toknum == VBP_FILE_)
+                   for (cb_ptr=cond_start; cb_ptr!=NULL; cb_ptr=cb_ptr->cb_chain)
+                       {
+                       if (cb_ptr -> baseline[1] == WILDCARD)      // ref station
+                           strncpy (cb_ptr -> vbp_file[0], char_values+tval, 256);
+                       else if (cb_ptr -> baseline[0] == WILDCARD) // rem station
+                           strncpy (cb_ptr -> vbp_file[1], char_values+tval, 256);
                        }
 
                break;
@@ -881,7 +937,6 @@ int parser (void)
                memset (parsed_codes,'\0',MAXFREQ);               /* pad with nulls */
                i = strlen (char_values + tval);
                i = (i > MAXFREQ) ? MAXFREQ : i;      /* move at most MAXFREQ chars */
-//               i = (i > 16) ? 16 : i;                /* move at most 16 chars */
                memcpy (parsed_codes, char_values + tval, i);
                break;
 
@@ -1029,3 +1084,14 @@ parsing_error (int state_num, int ntok)
    msg ("In state %s, encountered illegal token %s", 2,
          state[state_num], token_string[tokens[ntok].symbol]);
    }
+
+int fcode (char c, char *codes)
+	{
+	int i;
+	
+	for (i = 0; i < MAXFREQ; i++)
+		if (c == codes[i]) 
+            return i;
+    return -1;
+	}
+
