@@ -139,7 +139,12 @@ struct token_struct
 #define EST_PC_MANUAL_     111
 #define ADHOC_FLAG_FILE_   112
 #define PLOT_DATA_DIR_     113
-#define MAX_TOKENS         114   /* Increase to equal or exceed # tokens */
+#define CHAN_IDS_          114
+#define VBP_CORRECT_       115
+#define VBP_FIT_           116
+#define VBP_COEFFS_        117
+#define VBP_FILE_          118
+#define MAX_TOKENS         120   /* Increase to equal or exceed # tokens */
 
 
         /* Definitions of token categories */
