@@ -103,4 +103,7 @@ static char fchars[64] =
      'q','r','s','t','u','v','w','x','y','z','A','B','C','D','E','F',
      'G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V',
      'W','X','Y','Z','0','1','2','3','4','5','6','7','8','9','$','%'};
+
+static char *polab[4] =
+        { "LL", "RR", "LR", "RL" };
 #endif
